@@ -448,6 +448,86 @@ TEST_F(MoleculeTest, mass)
   EXPECT_DOUBLE_EQ(mol.mass(), 21.01408);
 }
 
+TEST_F(MoleculeTest, centerOfGeometry)
+{
+  Molecule mol;
+  Avogadro::Vector3 center = mol.centerOfGeometry();
+
+  Atom a8 = mol.addAtom(8);
+  mol.setAtomPosition3d(a8.index(), Avogadro::Vector3(0.0, 0.0, 0.0));
+  center = mol.centerOfGeometry();
+  EXPECT_DOUBLE_EQ(center.x(), 0.0);
+  EXPECT_DOUBLE_EQ(center.y(), 0.0);
+  EXPECT_DOUBLE_EQ(center.z(), 0.0);
+
+  Atom a = mol.addAtom(1);
+  mol.setAtomPosition3d(a.index(), Avogadro::Vector3(1.0, 0.0, 0.0));
+  center = mol.centerOfGeometry();
+  EXPECT_DOUBLE_EQ(center.x(), 0.5);
+  EXPECT_DOUBLE_EQ(center.y(), 0.0);
+  EXPECT_DOUBLE_EQ(center.z(), 0.0);
+
+  a = mol.addAtom(1);
+  mol.setAtomPosition3d(a.index(), Avogadro::Vector3(0.0, 1.0, -1.0));
+  center = mol.centerOfGeometry();
+  EXPECT_DOUBLE_EQ(center.x(), 1./3.);
+  EXPECT_DOUBLE_EQ(center.y(), 1./3.);
+  EXPECT_DOUBLE_EQ(center.z(), -1./3.);
+
+  a8.setAtomicNumber(9);
+  center = mol.centerOfGeometry();
+  EXPECT_DOUBLE_EQ(center.x(), 1./3.);
+  EXPECT_DOUBLE_EQ(center.y(), 1./3.);
+  EXPECT_DOUBLE_EQ(center.z(), -1./3.);
+}
+
+TEST_F(MoleculeTest, centerOfMass)
+{
+  Molecule mol;
+  Avogadro::Vector3 center = mol.centerOfMass();
+
+  Atom a8 = mol.addAtom(8);
+  mol.setAtomPosition3d(a8.index(), Avogadro::Vector3(0.0, 0.0, 0.0));
+  center = mol.centerOfMass();
+  EXPECT_DOUBLE_EQ(center.x(), 0.0);
+  EXPECT_DOUBLE_EQ(center.y(), 0.0);
+  EXPECT_DOUBLE_EQ(center.z(), 0.0);
+
+  Atom a = mol.addAtom(2);
+  mol.setAtomPosition3d(a.index(), Avogadro::Vector3(2.0, 0.0, 0.0));
+  center = mol.centerOfMass();
+  EXPECT_DOUBLE_EQ(center.x(), (2.0 * Avogadro::Core::Elements::mass(2) / mol.atomCount()) / mol.mass());
+  EXPECT_DOUBLE_EQ(center.y(), 0.0);
+  EXPECT_DOUBLE_EQ(center.z(), 0.0);
+
+  a = mol.addAtom(3);
+  mol.setAtomPosition3d(a.index(), Avogadro::Vector3(1.0, 3.0, -4.0));
+  center = mol.centerOfMass();
+  EXPECT_DOUBLE_EQ(center.x(), ((2.0 * Avogadro::Core::Elements::mass(2) + 1.0 * Avogadro::Core::Elements::mass(3)) / mol.atomCount()) / mol.mass());
+  EXPECT_DOUBLE_EQ(center.y(), (3.0 * Avogadro::Core::Elements::mass(3) / mol.atomCount()) / mol.mass());
+  EXPECT_DOUBLE_EQ(center.z(), (-4.0 * Avogadro::Core::Elements::mass(3) / mol.atomCount()) / mol.mass());
+
+  a8.setAtomicNumber(9);
+  center = mol.centerOfMass();
+  EXPECT_DOUBLE_EQ(center.x(), ((2.0 * Avogadro::Core::Elements::mass(2) + 1.0 * Avogadro::Core::Elements::mass(3)) / mol.atomCount()) / mol.mass());
+  EXPECT_DOUBLE_EQ(center.y(), (3.0 * Avogadro::Core::Elements::mass(3) / mol.atomCount()) / mol.mass());
+  EXPECT_DOUBLE_EQ(center.z(), (-4.0 * Avogadro::Core::Elements::mass(3) / mol.atomCount()) / mol.mass());
+}
+
+TEST_F(MoleculeTest, radius)
+{
+  Molecule mol;
+  EXPECT_DOUBLE_EQ(mol.radius(), 0.0);
+  Atom a = mol.addAtom(8);
+  mol.setAtomPosition3d(a.index(), Avogadro::Vector3(0.0, 0.0, 0.0));
+  EXPECT_DOUBLE_EQ(mol.radius(), 0.0);
+  a = mol.addAtom(1);
+  mol.setAtomPosition3d(a.index(), Avogadro::Vector3(2.0, 0.0, -1.0));
+  a = mol.addAtom(1);
+  mol.setAtomPosition3d(a.index(), Avogadro::Vector3(1.0, 3.0, -2.0));
+  EXPECT_DOUBLE_EQ(mol.radius(), sqrt(3.));
+}
+
 TEST_F(MoleculeTest, persistentBond)
 {
   Molecule molecule;
